@@ -5,18 +5,14 @@
 set -e
 
 ver=""
-if test -x /usr/bin/automake-1.6 ; then
-	ver="-1.6"
-fi
-if test -x /usr/bin/automake-1.7 ; then
-	ver="-1.7"
-fi
-#if test -x /usr/bin/automake-1.8 ; then
-#	ver="-1.8"
-#fi
+for amv in "1.6" "1.7" "1.8" "1.9" ; do
+	if test -x "/usr/bin/automakte-$amv" ; then
+		ver="-$amv"
+	fi
+done
 
 # The VERSION file defines our versioning
-PQXXVERSION=`grep '\<PQXXVERSION\>' VERSION | sed -e 's/^[[:space:]A-Z_]*//' | sed -e 's/[[:space:]]*#.*$//'`
+PQXXVERSION=`grep '\<PQXXVERSION\>' VERSION | sed -e 's/^[[:space:]A-Z_]*//' -e 's/[[:space:]]*#.*$//'`
 echo "libpqxx version $PQXXVERSION" 
 
 # Generate configure.ac based on current version numbers
@@ -28,8 +24,10 @@ sed -e "s/@PQXXVERSION@/$PQXXVERSION/g" configure.ac.in >configure.ac
 # Generate win32/test.mak (adding carriage returns to make it MS-DOS format)
 ./tools/maketestvcmak.pl test | sed -e 's/$/\r/' >win32/test.mak
 
-# Don't run autoheader to avoid overwriting customized config.h.in!
-# autoheader
+# Generate win32/libpqxx.mak
+./tools/makevcmake.pl src | sed -e 's/$/\r/' >win32/libpqxx.mak
+
+autoheader
 
 libtoolize --force --automake --copy
 aclocal${ver} -I . -I config/m4
@@ -45,5 +43,3 @@ else
 	echo Skipping configure process.
 fi
 
-	
-
