@@ -7,7 +7,7 @@
 #include <pqxx/pqxx>
 
 // For count_if workaround
-#include <pqxx/internalconfig.h>
+#include <pqxx/config-internal-compiler.h>
 
 using namespace PGSTD;
 using namespace pqxx;
